summaryrefslogtreecommitdiffstats
path: root/src/knemod/backends/backendbase.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-30 18:16:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-30 18:16:06 +0000
commit02a6c8f36311eb6225066df35adf8d00f9cd942b (patch)
treeceb91c373877f7a69209e184c81b53dc6f9402d7 /src/knemod/backends/backendbase.h
parent09e6e27fe85b2efb28072f1c81f6581fa6837d92 (diff)
downloadknemo-02a6c8f36311eb6225066df35adf8d00f9cd942b.tar.gz
knemo-02a6c8f36311eb6225066df35adf8d00f9cd942b.zip
TQt4 port knemo
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/knemo@1238869 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/knemod/backends/backendbase.h')
-rw-r--r--src/knemod/backends/backendbase.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/knemod/backends/backendbase.h b/src/knemod/backends/backendbase.h
index 183e40a..06fbb4d 100644
--- a/src/knemod/backends/backendbase.h
+++ b/src/knemod/backends/backendbase.h
@@ -20,8 +20,8 @@
#ifndef BACKENDBASE_H
#define BACKENDBASE_H
-#include <qdict.h>
-#include <qstring.h>
+#include <tqdict.h>
+#include <tqstring.h>
#include <klocale.h>
@@ -39,7 +39,7 @@
class BackendBase
{
public:
- BackendBase( QDict<Interface>& interfaces );
+ BackendBase( TQDict<Interface>& interfaces );
virtual ~BackendBase();
/**
@@ -50,7 +50,7 @@ public:
/**
* This function is called from KNemo whenever the
* backend shall update the information of the
* interfaces in the QDict.
*/
virtual void update() = 0;
@@ -62,7 +62,7 @@ protected:
*/
void updateComplete();
- const QDict<Interface>& mInterfaces;
+ const TQDict<Interface>& mInterfaces;
};
#endif // BACKENDBASE_H
@@ -50,7 +50,7 @@ public:
* This function is called from KNemo whenever the
* backend shall update the information of the
- * interfaces in the QDict.
+ * interfaces in the TQDict.
*/
virtual void update() = 0;